@@ -53,7 +53,7 @@ class ReactionFaceoff(object):
         self.showIntrosB.toggle()
         ypos = -(4000 - self.screen.get_height())
         self.numberOfGamesS = Slider(self, w-160-90, ypos+300, 90, 4000, "right")
-        self.numberOfGamesS.setCaption("Number of games")
+        self.numberOfGamesS.setCaption("Number of rounds")
         self.numberOfGamesS.setColor((0, 71, 171))
         self.quitB = Button(self, 160, 0, 140, 60, "down")
         self.quitB.setCaption("Quit")
@@ -252,8 +252,7 @@ class ReactionFaceoff(object):
         self.screen.blit(self.banner, (160,center[1]-(self.banner.get_height()/2)))
         self.drawText("Reaction face-off", center,
                                   self.screen.get_height()-40, "right")
-        self.drawMainText('''
-        A fast-paced 2-player game that puts your reflexes, knowledge and brainpower to the test. Written in python using pygame, released under the GPLv3. \n (C) 2010 Carol Alexandru \n <sphaerodactylus@gmail.com>''',
+        self.drawMainText('''A fast-paced 2-player game that puts your reflexes, knowledge and brainpower to the test. Written in python using pygame, released under the GPLv3. \n (C) 2010 Carol Alexandru \n <sphaerodactylus@gmail.com>''',
         single=2, size=28)
         self.button1.draw()
         self.button2.draw()
@@ -268,14 +267,11 @@ class ReactionFaceoff(object):
     def showHelpScreen(self):
         self.clearPlayArea()
         center = (self.screen.get_width()/2, self.screen.get_height()/2)
-        self.drawText('''
-        Compete against your opponent in various disciplines. If you want to be introduced into each game, leave the intros on. If you already know your way around, turn them off.
+        self.drawText('''Round after round you compete in different games against your opponent. Every minigame makes a statement, and if it becomes true, you have to hit your button to gain a point. If you're wrong, your opponent gets a point.
         
-        Set the number of rounds. 
+        You can disable games you want to avoid from the games menu.
         
-        You can disable games you want to avoid from the games menu. 
-        
-        Press Q to quit at any time, press R to return to the main menu during a game 
+        Press Q to quit at any time, press R to return to the main menu during a game.
         ''', center, self.screen.get_height()-40, "right", size=30)
         self.button1.draw()
         self.button2.draw()
@@ -302,7 +298,8 @@ class ReactionFaceoff(object):
             button = Button(self, slots[i][0],slots[i][1],
                            w/rows-4, h/2-4, "right")
             self.gameScreenButtons.append(button)
-            button.toggle()
+            if game not in self.undesiredGames:
+                button.toggle()
             button.setCaption(self.minigames[i], textSize=30)
             button.draw()
         button = Button(self, slots[len(slots)-1][0],slots[len(slots)-1][1],
